@@ -11,13 +11,11 @@ for(@makefiles)
 		my $file = $_;
 		my ($filedir) = ($file =~ /(.*)Makefile\.am$/);
 
-		print "Processing $file\n";
-
 		my $content = LoadFile($file);
 		if($content eq '')
 			{
-				print "Couldn't open file for reading, skipped.\n";
-				next;
+				print "$file is empty\n";
+#				next;
 			}
 
 		# Suppress multi-lines ...
@@ -28,7 +26,6 @@ for(@makefiles)
 		my ($headersname, $headers) = ($content =~ /^(.*)HEADERS\s*=\s*(.*)$/m);
 		if(!defined $headers)
 			{
-				print " > no HEADERS list <\n";
 				$headers = "";
 			}
 
@@ -42,6 +39,8 @@ for(@makefiles)
 			}
 
 		# Check against real list ...
+		$found_error = 0;
+
 		for(FileList($filedir))
 			{
 				my $name = $_;
@@ -51,7 +50,13 @@ for(@makefiles)
 
 				if(!defined $files{$name})
 					{
-						print "  you must include $name !!\n";
+						if(!$found_error)
+							{
+								$found_error = 1;
+								print "\n\n$file is missing the following:\n";
+							}
+							
+						print "\t$name \\\n";
 					}
 			}
 
