@@ -209,6 +209,9 @@ public:
 	friend std::istream& operator>>(std::istream&, type_t&);
 };
 
+/// Convenience function for setting all companions of a raw polygon edges
+void set_companions(k3d::polyhedron& Polyhedron);
+
 /////////////////////////////////////////////////////////////////////////////
 // linear_curve
 
