@@ -544,22 +544,36 @@ private:
 		// Sanity checks ...
 		return_if_fail(m_source_object.object());
 		return_if_fail(m_source_property.get());
-//		return_if_fail(m_destination_object.object());
-//		return_if_fail(m_destination_property.get());
+		
 		if(m_destination_property.get())
 			return_if_fail(m_source_property.get()->type() == m_destination_property.get()->type());
 
 		// Prevent circular dependencies!
-		if(k3d::is_cyclic(m_document, *m_destination_property.get(), m_source_property.get()))
+		if(m_destination_object.object() && m_destination_property.get())
 			{
-				if(k3d::application().user_interface())
-					k3d::application().user_interface()->error_message("Cannot create circular DAG dependency", "Connect Properties:");
+				if(k3d::is_cyclic(m_document, *m_destination_property.get(), m_source_property.get()))
+					{
+						if(k3d::application().user_interface())
+							k3d::application().user_interface()->error_message("Cannot create circular DAG dependency", "Connect Properties:");
 
-				std::cerr << error << "Cannot create circular DAG dependency" << std::endl;
-				return;
+						std::cerr << error << "Cannot create circular DAG dependency" << std::endl;
+						return;
+					}
 			}
 
-		k3d::record_state_change_set change(m_document, "Connect " + m_source_object.object()->name() + "." + m_source_property.get()->name() + " -> " + m_destination_object.object()->name() + "." + m_destination_property.get()->name());
+		std::string state_change_name;
+		if(m_destination_object.object() && m_destination_property.get())
+			{
+				state_change_name =
+					"Connect " + m_source_object.object()->name() + "." + m_source_property.get()->name() 
+						+ " -> " + m_destination_object.object()->name() + "." + m_destination_property.get()->name();
+			}
+		else
+			{
+				state_change_name =
+					"Disconnect " + m_source_object.object()->name() + "." + m_source_property.get()->name();
+			}
+		k3d::record_state_change_set change(m_document, state_change_name);
 
 		k3d::idag::dependencies_t dependencies;
 		dependencies.insert(std::make_pair(m_destination_property.get(), m_source_property.get()));
