@@ -194,6 +194,9 @@ private:
 
 	k3d::iobject* m_current_mesh_object;
 
+	// Save new polyhedra to set companions
+	std::vector<k3d::polyhedron*> m_polyhedra;
+
 	bool create_mesh(k3d::idocument& Document)
 	{
 		// Create document object ...
@@ -216,6 +219,7 @@ private:
 
 		k3d::polyhedron* polyhedron = new k3d::polyhedron();
 		return_val_if_fail(polyhedron, false);
+		m_polyhedra.push_back(polyhedron);
 
 		polyhedron->material = default_material;
 
@@ -323,6 +327,10 @@ bool obj_reader_implementation::read_file(k3d::idocument& Document, const boost:
 				}
 		}
 
+	// Set companions for each new polyhedron
+	for(std::vector<k3d::polyhedron*>::iterator p = m_polyhedra.begin(); p != m_polyhedra.end(); ++p)
+		k3d::set_companions(*(*p));
+
 	return true;
 }
 
