@@ -315,37 +315,6 @@ k3d::vector3 mult_scales(const k3d::vector3& v1, const k3d::vector3& v2)
 
 typedef std::vector<k3d::vector3> coordinates_t;
 
-bool create_polygon(coordinates_t& points, k3d::mesh* mesh)
-{
-	return_val_if_fail(mesh, false);
-
-	k3d::polyhedron::edges_t edges;
-	coordinates_t::const_iterator point = points.begin();
-	for(; point != points.end(); point++)
-		{
-			k3d::point* new_point = new k3d::point(*point);
-			return_val_if_fail(new_point, false);
-
-			mesh->points.push_back(new_point);
-			edges.push_back(new k3d::split_edge(new_point));
-		}
-
-	k3d::loop_edges(edges.begin(), edges.end());
-
-	k3d::polyhedron* polyhedron = new k3d::polyhedron();
-	return_val_if_fail(polyhedron, false);
-
-	polyhedron->edges.insert(polyhedron->edges.end(), edges.begin(), edges.end());
-
-	k3d::face* const face = new k3d::face(*edges.begin());
-	return_val_if_fail(face, false);
-
-	polyhedron->faces.push_back(face);
-	mesh->polyhedra.push_back(polyhedron);
-
-	return true;
-}
-
 /////////////////////////////////////////////////////////////////////////////
 // rib_reader_implementation
 
@@ -454,6 +423,9 @@ private:
 	k3d::iobject* m_current_material;
 	k3d::iobject* m_current_shader;
 
+	// Save new polyhedra to set companions
+	std::vector<k3d::polyhedron*> m_polyhedra;
+
 	bool create_mesh(k3d::idocument& Document)
 	{
 		// Create document object ...
@@ -484,6 +456,7 @@ private:
 
 		k3d::polyhedron* polyhedron = new k3d::polyhedron();
 		return_val_if_fail(polyhedron, false);
+		m_polyhedra.push_back(polyhedron);
 
 		m_current_mesh->polyhedra.push_back(polyhedron);
 
@@ -520,6 +493,38 @@ private:
 		return true;
 	}
 
+	bool create_polygon(coordinates_t& points, k3d::mesh* mesh)
+	{
+		return_val_if_fail(mesh, false);
+
+		k3d::polyhedron::edges_t edges;
+		coordinates_t::const_iterator point = points.begin();
+		for(; point != points.end(); point++)
+			{
+				k3d::point* new_point = new k3d::point(*point);
+				return_val_if_fail(new_point, false);
+
+				mesh->points.push_back(new_point);
+				edges.push_back(new k3d::split_edge(new_point));
+			}
+
+		k3d::loop_edges(edges.begin(), edges.end());
+
+		k3d::polyhedron* polyhedron = new k3d::polyhedron();
+		return_val_if_fail(polyhedron, false);
+		m_polyhedra.push_back(polyhedron);
+
+		polyhedron->edges.insert(polyhedron->edges.end(), edges.begin(), edges.end());
+
+		k3d::face* const face = new k3d::face(*edges.begin());
+		return_val_if_fail(face, false);
+
+		polyhedron->faces.push_back(face);
+		mesh->polyhedra.push_back(polyhedron);
+
+		return true;
+	}
+
 	bool create_transform(k3d::idocument& Document)
 	{
 		k3d::iobject* const transform = k3d::create_document_plugin(k3d::classes::Transform(), Document);
@@ -1635,6 +1640,10 @@ bool rib_reader_implementation::read_file(k3d::idocument& Document, const boost:
 	for(; pi != main_node.end(); pi++)
 		parse_subpree(*pi, Document);
 
+	// Set companions for each new polyhedron
+	for(std::vector<k3d::polyhedron*>::iterator p = m_polyhedra.begin(); p != m_polyhedra.end(); ++p)
+		k3d::set_companions(*(*p));
+
 	return true;
 }
 
