@@ -295,7 +295,10 @@ public:
 										unsigned long companion_index = 0;
 										return_if_fail(sdpxml::ParseAttribute(*xml_edge, "companion", companion_index));
 										return_if_fail(companion_index <= edges.size());
-
+										
+										double sharpness = 0.0;
+										sdpxml::ParseAttribute(*xml_edge, "crease", sharpness);
+										
 										if(vertex_index)
 											(*edge)->vertex = mesh->points[vertex_index-1];
 
@@ -304,6 +307,8 @@ public:
 
 										if(companion_index)
 											(*edge)->companion = edges[companion_index-1];
+										
+										(*edge)->tags["crease"] = sharpness;
 
 										++edge;
 									}
@@ -742,11 +747,20 @@ public:
 								sdpxml::Element& xml_edges = xml_polyhedron.Append(sdpxml::Element("edges"));
 								for(k3d::polyhedron::edges_t::const_iterator edge = (*polyhedron)->edges.begin(); edge != (*polyhedron)->edges.end(); ++edge)
 									{
+										double sharpness = 0.0;
+										for(k3d::parameters_t::const_iterator tag = (*edge)->tags.begin(); tag != (*edge)->tags.end(); ++tag)
+											{
+												if(tag->first == "crease" && (tag->second.type() == typeid(k3d::ri::real)))
+												{
+													sharpness = boost::any_cast<double>(tag->second);
+												}
+											}
 										sdpxml::Element& xml_edge = xml_edges.Append(
 											sdpxml::Element("edge", "",
 												sdpxml::Attribute("vertex", k3d::string_cast(point_map[(*edge)->vertex])),
 												sdpxml::Attribute("faceclockwise", k3d::string_cast(edge_map[(*edge)->face_clockwise])),
-												sdpxml::Attribute("companion", k3d::string_cast(edge_map[(*edge)->companion]))));
+												sdpxml::Attribute("companion", k3d::string_cast(edge_map[(*edge)->companion])),
+												sdpxml::Attribute("crease", k3d::string_cast(sharpness))));
 
 										save_parameters(xml_edge, (*edge)->facevarying_data, k3d::ri::FACEVARYING);
 									}
