@@ -37,7 +37,8 @@
 #include <k3dsdk/transformable.h>
 #include <k3dsdk/viewport.h>
 
-#include "blobby_polygonizer.h"
+#include <surface_polygonizer_library/blobby_polygonizer.h>
+
 #include "subdiv_algorithms.h"
 
 #include <limits>
@@ -210,6 +211,10 @@ public:
 	}
 };
 
+typedef std::vector<k3d::vector3> vertices_t;
+typedef std::vector<unsigned long> polygon_t;
+typedef std::vector<polygon_t> polygons_t;
+
 } // namespace detail
 
 /////////////////////////////////////////////////////////////////////////////
@@ -314,7 +319,7 @@ public:
 						detail::vertices_t blobby_vertices;
 						detail::vertices_t blobby_normals;
 						detail::polygons_t blobby_polygons;
-						detail::polygonize_blobby(*blobby, 0, blobby_vertices, blobby_normals, blobby_polygons);
+						polygonize_blobby(*blobby, 0, blobby_vertices, blobby_normals, blobby_polygons);
 
 						// Save surface
 						blobby_cache_map[*blobby] = blobby_surfaces_vertices.size();
@@ -334,8 +339,10 @@ public:
 
 				if(is_sds)
 					{
+						k3d::mesh creased_mesh;
+						subdiv::crease(*mesh, creased_mesh);
 						m_sds_cache = new k3d::mesh();
-						subdiv::catmull_clark(m_sds_levels.property_value(), *mesh, *m_sds_cache);
+						subdiv::catmull_clark(m_sds_levels.property_value(), creased_mesh, *m_sds_cache);
 					}
 			}
 	}
