@@ -1518,6 +1518,9 @@ public:
 		return_val_if_fail(is_valid(polyhedron), 0);
 		//assert_warning(is_solid(polyhedron));
 
+		// Set companions
+		k3d::set_companions(polyhedron);
+
 		return mesh.release();
 	}
 
