@@ -1136,6 +1136,8 @@ PyMethodDef python_mesh::methods[] =
 	{"create_mesh_instance", create_mesh_instance, METH_VARARGS, "Create an instance for a mesh object"},
 	{"create_point", create_point, METH_VARARGS, "Create a new point, add it to the point list"},
 	{"get_points", get_points, METH_VARARGS, "Get mesh points as a list"},
+	{"get_point_position", get_point_position, METH_VARARGS, "Get a point position from its index in points array"},
+	{"set_point_position", set_point_position, METH_VARARGS, "Set a point position from its index in points array"},
 	{"create_polyhedron", create_polyhedron, METH_VARARGS, "Create a new polyhedron, add it to the polyhedra list"},
 	{"get_polyhedra", get_polyhedra, METH_VARARGS, "Get mesh polyhedra as a list"},
 	{"add_blobby", add_blobby, METH_VARARGS, "Adds a blobby object"},
@@ -1235,6 +1237,41 @@ PyObject* python_mesh::get_points(PyObject* self, PyObject* args)
 	return list;
 }
 
+PyObject* python_mesh::get_point_position(PyObject* self, PyObject* args)
+{
+	PyObject* py_mesh;
+	unsigned long py_index;
+	return_val_if_fail(PyArg_ParseTuple(args, "Ol", &py_mesh, &py_index), PYVAL_FALSE);
+
+	k3d::mesh* const mesh = dynamic_cast<k3d::mesh*>(Interface(py_mesh));
+	return_val_if_fail(mesh, PYVAL_FALSE);
+	return_val_if_fail(py_index < mesh->points.size(), PYVAL_FALSE);
+
+	k3d::vector3 position = mesh->points[py_index]->position;
+
+	return ConvertTuple3(position);
+}
+
+PyObject* python_mesh::set_point_position(PyObject* self, PyObject* args)
+{
+	PyObject* py_mesh;
+	unsigned long py_index;
+	PyObject* py_vector;
+	return_val_if_fail(PyArg_ParseTuple(args, "OlO", &py_mesh, &py_index, &py_vector), PYVAL_FALSE);
+
+	k3d::mesh* const mesh = dynamic_cast<k3d::mesh*>(Interface(py_mesh));
+	return_val_if_fail(mesh, PYVAL_FALSE);
+	return_val_if_fail(py_index < mesh->points.size(), PYVAL_FALSE);
+
+	k3d::vector3 position = k3d::vector3(0, 0, 0);
+	if(py_vector != Py_None)
+		position = ConvertVector3(py_vector);
+
+	mesh->points[py_index]->position = position;
+
+	return PYVAL_TRUE;
+}
+
 PyObject* python_mesh::create_polyhedron(PyObject* self, PyObject* args)
 {
 	PyObject* py_mesh;
@@ -1403,6 +1440,7 @@ PyMethodDef python_polyhedron::methods[] =
 {
 	{"create_face", create_face, METH_VARARGS, "Create a new face"},
 	{"add_point_to_face", add_point_to_face, METH_VARARGS, "Add a new edge to an existing face"},
+	{"create_face_from_vertex_indices", create_face_from_vertex_indices, METH_VARARGS, "Create a face from vertex indices list"},
 	{"get_faces", get_faces, METH_VARARGS, "Return face list"},
 	{0, 0, 0, 0}
 };
@@ -1414,9 +1452,9 @@ PyObject* python_polyhedron::create_face(PyObject* self, PyObject* args)
 	PyObject* py_point;
 	return_val_if_fail(PyArg_ParseTuple(args, "OOO", &py_polyhedron, &py_mesh, &py_point), PYVAL_FALSE);
 
+	// TODO: check that point and polyhedron belong to the same mesh
 	k3d::polyhedron* const polyhedron = dynamic_cast<k3d::polyhedron*>(Interface(py_polyhedron));
 	return_val_if_fail(polyhedron, PYVAL_FALSE);
-	// TODO: check that point and polyhedron belong to the same mesh
 	k3d::point* const point = dynamic_cast<k3d::point*>(python_point::Interface(py_point));
 	return_val_if_fail(point, PYVAL_FALSE);
 
@@ -1439,9 +1477,9 @@ PyObject* python_polyhedron::add_point_to_face(PyObject* self, PyObject* args)
 	PyObject* py_point;
 	return_val_if_fail(PyArg_ParseTuple(args, "OOOO", &py_polyhedron, &py_mesh, &py_face, &py_point), PYVAL_FALSE);
 
+	// TODO: check that point and polyhedron belong to the same mesh
 	k3d::polyhedron* const polyhedron = dynamic_cast<k3d::polyhedron*>(Interface(py_polyhedron));
 	return_val_if_fail(polyhedron, PYVAL_FALSE);
-	// TODO: check that point and polyhedron belong to the same mesh
 	k3d::face* const face = dynamic_cast<k3d::face*>(python_face::Interface(py_face));
 	return_val_if_fail(face, PYVAL_FALSE);
 	k3d::point* const point = dynamic_cast<k3d::point*>(python_point::Interface(py_point));
@@ -1453,15 +1491,57 @@ PyObject* python_polyhedron::add_point_to_face(PyObject* self, PyObject* args)
 	polyhedron->edges.push_back(new_edge);
 	k3d::split_edge* edge = face->first_edge;
 	while(edge->face_clockwise && edge->face_clockwise != face->first_edge)
-		{
-			edge = edge->face_clockwise;
-		}
+		edge = edge->face_clockwise;
+
 	edge->face_clockwise = new_edge;
 	new_edge->face_clockwise = face->first_edge;
 
 	return python_face::Create(face);
 }
 
+PyObject* python_polyhedron::create_face_from_vertex_indices(PyObject* self, PyObject* args)
+{
+	PyObject* py_polyhedron;
+	PyObject* py_mesh;
+	PyObject* py_index_list;
+	return_val_if_fail(PyArg_ParseTuple(args, "OOO", &py_polyhedron, &py_mesh, &py_index_list), PYVAL_FALSE);
+
+	k3d::mesh* const mesh = dynamic_cast<k3d::mesh*>(python_mesh::Interface(py_mesh));
+	return_val_if_fail(mesh, PYVAL_FALSE);
+	k3d::polyhedron* const polyhedron = dynamic_cast<k3d::polyhedron*>(Interface(py_polyhedron));
+	return_val_if_fail(polyhedron, PYVAL_FALSE);
+	return_val_if_fail(PySequence_Check(py_index_list), PYVAL_FALSE);
+
+	const unsigned long face_size = PySequence_Size(py_index_list);
+	return_val_if_fail(face_size >= 3, PYVAL_FALSE);
+
+	// Create face
+	const unsigned long max_index = mesh->points.size();
+	k3d::polyhedron::edges_t edges;
+	for(unsigned long i = 0; i < face_size; ++i)
+		{
+			PyObject* py_item = PySequence_GetItem(py_index_list, i);
+			return_val_if_fail(py_item, PYVAL_FALSE);
+
+			const unsigned long point_index = PyLong_AsLong(py_item);
+			return_val_if_fail(point_index < max_index, PYVAL_FALSE);
+
+			k3d::split_edge* const new_edge = new k3d::split_edge(mesh->points[point_index]);
+			return_val_if_fail(new_edge, PYVAL_FALSE);
+
+			edges.push_back(new_edge);
+		}
+
+	k3d::loop_edges(edges.begin(), edges.end());
+	polyhedron->edges.insert(polyhedron->edges.end(), edges.begin(), edges.end());
+
+	k3d::face* const face = new k3d::face(edges.front());
+	return_val_if_fail(face, PYVAL_FALSE);
+	polyhedron->faces.push_back(face);
+
+	return python_face::Create(face);
+}
+
 PyObject* python_polyhedron::get_faces(PyObject* self, PyObject* args)
 {
 	PyObject* py_polyhedron;
