@@ -99,17 +99,17 @@ protected:
 				else if(argument->storage.type() == typeid(string_storage_t*))
 					{
 						string_storage_t& storage = *boost::any_cast<string_storage_t*>(argument->storage);
-						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::string>(storage.value())));
+						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::string>(storage.property_value())));
 					}
 				else if(argument->storage.type() == typeid(scalar_storage_t*))
 					{
 						scalar_storage_t& storage = *boost::any_cast<scalar_storage_t*>(argument->storage);
-						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::real>(storage.value())));
+						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::real>(storage.property_value())));
 					}
 				else if(argument->storage.type() == typeid(color_storage_t*))
 					{
 						color_storage_t& storage = *boost::any_cast<color_storage_t*>(argument->storage);
-						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::color>(storage.value())));
+						results.push_back(k3d::ri::parameter(argument->name, k3d::ri::CONSTANT, static_cast<k3d::ri::color>(storage.property_value())));
 					}
 				else if(argument->storage.type() == typeid(texture_storage_t*))
 					{
